package com.tourism.webadmin.app.website.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import cn.dev33.satoken.annotation.SaIgnore;
import com.github.pagehelper.page.PageMethod;
import com.tourism.common.core.annotation.MyRequestBody;
import com.tourism.common.core.constant.ErrorCodeEnum;
import com.tourism.common.core.object.*;
import com.tourism.common.core.util.MyModelUtil;
import com.tourism.common.core.util.MyPageUtil;
import com.tourism.webadmin.back.dto.JobProjectDto;
import com.tourism.webadmin.back.model.DirectoryInfo;
import com.tourism.webadmin.back.model.JobProject;
import com.tourism.webadmin.back.service.JobProjectService;
import com.tourism.webadmin.back.service.TourismProjectService;
import com.tourism.webadmin.back.vo.JobProjectVo;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

import static java.util.stream.Collectors.toList;

/**
 * 网页劳务项目管理操作控制器类。
 *
 * @author 吃饭睡觉
 * @date 2024-09-06
 */
@Tag(name = "门户劳务项目管理接口")
@Slf4j
@RestController
@SaIgnore
@RequestMapping("/website/basic/jobProject")
public class JobProjectToWebController {

    @Autowired
    private JobProjectService jobProjectService;
    @Autowired
    private TourismProjectService tourismProjectService;
    /**
     * 列出符合过滤条件的劳务项目管理列表。
     *
     * @param jobProjectDtoFilter 过滤对象。
     * @param orderParam 排序参数。
     * @param pageParam 分页参数。
     * @return 应答结果对象，包含查询结果集。
     */
    @PostMapping("/list")
    public ResponseResult<MyPageData<JobProjectVo>> list(
            @MyRequestBody JobProjectDto jobProjectDtoFilter,
            @MyRequestBody MyOrderParam orderParam,
            @MyRequestBody MyPageParam pageParam) {
        if(jobProjectDtoFilter.getBelongTab() == null){
            return ResponseResult.error(ErrorCodeEnum.ARGUMENT_NULL_EXIST,"所属分类(belongTab)不能为空!");
        }
        //如果belongTab小于1000并且大于10.则表明查询的是一级菜单
        if(jobProjectDtoFilter.getBelongTab()>=10 && jobProjectDtoFilter.getBelongTab()<1000){
            DirectoryInfo filter = new DirectoryInfo();
            filter.setParentId(jobProjectDtoFilter.getBelongTab());
            filter.setEnable(1);
            List<DirectoryInfo> directoryInfoList = tourismProjectService.getDirectoryInfoList(filter, null);
            jobProjectDtoFilter.setBelongTab(null);
            jobProjectDtoFilter.setDirectoryInfoIds(directoryInfoList.stream().map(DirectoryInfo::getId).collect(toList()));
        }
        JobProject jobProjectFilter = MyModelUtil.copyTo(jobProjectDtoFilter, JobProject.class);
        //首页展示的为启用的内容
        jobProjectFilter.setEnable(1);
        String orderBy = MyOrderParam.buildOrderBy(orderParam, JobProject.class);
        if (pageParam != null) {
            PageMethod.startPage(pageParam.getPageNum(), pageParam.getPageSize(), pageParam.getCount());
        }
        List<JobProject> jobProjectList = jobProjectService.getJobProjectListWithRelation(jobProjectFilter, orderBy);
        return ResponseResult.success(MyPageUtil.makeResponseData(jobProjectList, JobProjectVo.class));
    }

    /**
     * 查看指定劳务项目管理对象详情。
     *
     * @param id 指定对象主键Id。
     * @return 应答结果对象，包含对象详情。
     */
//    @SaCheckPermission("jobProject.view")
    @GetMapping("/detail")
    public ResponseResult<JobProjectVo> detail(@RequestParam Long id) {
        JobProject jobProject = jobProjectService.getByIdWithRelation(id, MyRelationParam.full());
        if (jobProject == null) {
            return ResponseResult.error(ErrorCodeEnum.DATA_NOT_EXIST);
        }
        JobProjectVo jobProjectVo = MyModelUtil.copyTo(jobProject, JobProjectVo.class);
        return ResponseResult.success(jobProjectVo);
    }
}
